@@ -1,7 +1,10 @@
 import grtoolkit.Circuits.AC
-import grtoolkit.Circuits.Conductance
+import grtoolkit.Circuits.Capacitors as Capacitors
+import grtoolkit.Circuits.Conductance as Conductance
 import grtoolkit.Circuits.Filters
+import grtoolkit.Circuits.Inductors as Inductors
 import grtoolkit.Circuits.OpAmps
+import grtoolkit.Circuits.Resistors as Resistors
 import grtoolkit.Circuits.Transformations
 import grtoolkit.Circuits.Transistors
 from grtoolkit.Math import solveEqs, solveSimultaneousEqs
@@ -29,30 +32,6 @@ def BasicLaws(find, printEq=False, **kwargs):
     eq.append("Eq(i,(v_higher-v_lower)/R)")
     return solveEqs(eq, find, printEq=printEq, **kwargs)
 
-def Resistance(find, printEq=False, **kwargs):
-    """variables: 
-                R=resistance
-                p=density
-                l=length
-                A=cross sectional area"""
-    eq = list()
-    eq.append("Eq(R,p*l/A)")    
-    return solveEqs(eq, find, printEq=printEq, **kwargs)
-
-def Capacitance(find="C", printEq=False, **kwargs):
-    """
-    Usage: the ratio of the charge on one plate of a capacitor to the voltage difference between the two plates, measured in farads (F).
-
-
-    variables: 
-                C = capacitance
-                epsilon = permitivity of the dielectric material between plates
-                A = surface area of each plate
-                d = distance between plates"""
-    eq = list()
-    eq.append("Eq(C,epsilon*A/d)")    
-    return solveEqs(eq, find, printEq=printEq, **kwargs)
-
 def KCL(eq):
     """
     Conservation of current.
@@ -76,7 +55,7 @@ def KCL(eq):
     """
     return solveSimultaneousEqs(eq)
 
-def KVL(v_list):
+def KVL(eq):
     """
     Conservation of Voltage
     Sum of all voltages around a closed path (or loop) is 0
@@ -100,14 +79,6 @@ def KVL(v_list):
     # TO BE COMPLETED
     return solveSimultaneousEqs(eq)
 
-def ResistorsInSeries(r_list):
-    """Resistors connected in series is the sum of the individual resistances"""
-    return sum(r_list)
-
-def ResistorsInParallel(r_list):
-    sumOfInverse = sum([1/r for r in r_list])
-    return 1/sumOfInverse
-
 def voltageDivision(v_in, r_list_ordered, showWork=False):
     """
     Voltage is divided among the resistors in direct proportion to their resistances; 
@@ -129,18 +100,6 @@ def currentDivision(i_in, r_branch_list_ordered, showWork=False):
         print("Adjust directions as necessary after getting result.")
     return currents
 
-# def Conductance(r):
-#     # Look at functions as objects
-#     # https://medium.com/python-pandemonium/function-as-objects-in-python-d5215e6d1b0d
-#     return 1/r
-
-# def ConductanceInSeries(g_list):
-#     return ResistorsInParallel(g_list)
-
-# def ConductanceInParallel(g_list):
-#     return ResistorsInSeries(g_list)
-
-
 def NodalSimpleAnalysis(vh, vl, r):
     """Current flows from a higher potential to a lower potential in a resistor"""
     i = (vh-vl)/r
